"use client";

import Image from "next/image";
import { useSearchParams } from "next/navigation";
import { useEffect, useRef } from "react";

import Tabs, { TabsRef } from "@/components/common/tabs/tabs";
import { TabsProvider } from "@/contexts/tabs-context";
import { Locale } from "@/i18n/routing";
import { useCart } from "@/servers/data/use-cart";
import { Loader2 } from "lucide-react";

interface CartPageClientProps {
	locale: Locale;
	cartTabs: any[];
}

export default function CartPageClient({ locale, cartTabs }: CartPageClientProps) {
	const tabsRef = useRef<TabsRef>(null);
	const searchParams = useSearchParams();
	const { isLoading } = useCart();

	// Initialize active tab based on URL parameter
	useEffect(() => {
		const tabParam = searchParams.get("tab");
		if (tabParam && tabsRef.current) {
			const tabIndex = parseInt(tabParam, 10);
			if (!isNaN(tabIndex) && tabIndex >= 0 && tabIndex < cartTabs.length) {
				tabsRef.current.setActiveTab(tabIndex);
			}
		}
	}, [searchParams, cartTabs.length]);

	return (
		<TabsProvider tabsRef={tabsRef}>
			<div className="relative mx-auto max-w-10xl p-4 md:p-8 lg:p-12 xl:p-20">

				{
					isLoading ? <Loader2 className="animate-spin mx-auto" /> :

						<Tabs ref={tabsRef} tabs={cartTabs} locale={locale} />

				}

				<Image
					src="/images/shared/Vector.png"
					alt="cart"
					width={1000}
					height={200}
					className="absolute -left-12 -top-32 -z-10"
				/>
			</div>
		</TabsProvider>
	);
} 